pub fn init()Expand description
Call this function before using any other libspelling functions in your applications. It will initialize everything needed to operate the library.
pub fn init()Call this function before using any other libspelling functions in your applications. It will initialize everything needed to operate the library.