pub struct TextBufferAdapter { /* private fields */ }Expand description
SpellingTextBufferAdapter implements helpers to easily add spellchecking
capabilities to a [gtk_source::Buffer][crate::gtk_source::Buffer].
Properties
buffer
The [gtk_source::Buffer][crate::gtk_source::Buffer].
Readable | Writeable | Construct Only
checker
The Checker.
Readable | Writeable
enabled
Whether spellcheck is enabled.
Readable | Writeable
language
The language code, such as en_US.
Readable | Writeable
Implements
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TextBufferAdapter
impl TextBufferAdapter
Sourcepub fn new(buffer: &impl IsA<Buffer>, checker: &Checker) -> TextBufferAdapter
pub fn new(buffer: &impl IsA<Buffer>, checker: &Checker) -> TextBufferAdapter
Sourcepub fn builder() -> TextBufferAdapterBuilder
pub fn builder() -> TextBufferAdapterBuilder
Creates a new builder-pattern struct instance to construct TextBufferAdapter objects.
This method returns an instance of TextBufferAdapterBuilder which can be used to create TextBufferAdapter objects.
Sourcepub fn buffer(&self) -> Option<Buffer>
pub fn buffer(&self) -> Option<Buffer>
Gets the underlying buffer for the adapter.
Returns
a [gtk_source::Buffer][crate::gtk_source::Buffer]
Sourcepub fn is_enabled(&self) -> bool
pub fn is_enabled(&self) -> bool
Sourcepub fn invalidate_all(&self)
pub fn invalidate_all(&self)
Invalidate the spelling engine, to force parsing again.
Invalidation is automatically done on [loading][struct@crate::gtk_source::Buffer#loading]
change.
Sourcepub fn set_checker(&self, checker: &Checker)
pub fn set_checker(&self, checker: &Checker)
Sourcepub fn set_enabled(&self, enabled: bool)
pub fn set_enabled(&self, enabled: bool)
Sourcepub fn set_language(&self, language: &str)
pub fn set_language(&self, language: &str)
Sourcepub fn update_corrections(&self)
pub fn update_corrections(&self)
Looks at the current cursor position and updates the list of corrections based on the current word.
Use this to force an update immediately rather than after the automatic timeout caused by cursor movements.
pub fn connect_checker_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_enabled_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
pub fn connect_language_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId